#[repr(u64)]pub enum WireType {
False = 0,
True = 1,
UInt64 = 2,
SInt64 = 3,
Bytes = 4,
String = 5,
Message = 6,
Sequence = 7,
}Expand description
Wire type identifiers for Veriform types
Variants
False = 0
False (boolean)
True = 1
True (boolean)
UInt64 = 2
64-bit unsigned integer
SInt64 = 3
64-bit (zigzag) signed integer
Bytes = 4
Binary data
String = 5
Unicode string
Message = 6
Nested Veriform message
Sequence = 7
Sequences
Implementations
Sourceimpl WireType
impl WireType
Sourcepub fn from_unmasked(value: u64) -> Self
pub fn from_unmasked(value: u64) -> Self
Decode a WireType from an unmasked u64
Sourcepub fn is_dynamically_sized(self) -> bool
pub fn is_dynamically_sized(self) -> bool
Is this a dynamically-sized WireType?
Sourcepub fn decoding_error(self) -> Error
pub fn decoding_error(self) -> Error
Create a decoding error for this given wire type.
This method is primarily intended to be used by veriform_derive.